apply_n3_patch

Function apply_n3_patch 

pub fn apply_n3_patch(
    target: Graph,
    patch: &str,
) -> Result<PatchOutcome, PodError>
Apply a solid-protocol N3 PATCH document to target.

Recognised clauses:

_:rename a solid:InsertDeletePatch ;
  solid:inserts { <#s> <#p> <#o> . } ;
  solid:deletes { <#s> <#p> <#o> . } ;
  solid:where   { <#s> <#p> ?var . } .

The parser is deliberately permissive: it hunts for insert / delete / where blocks delimited by curly braces anywhere in the body. The contents of each block are parsed as N-Triples.