generate_html

Function generate_html 

pub fn generate_html(
    resource_url: &str,
    config: &MashlibConfig,
    embed_json_ld: Option<&str>,
) -> String
Generate the mashlib HTML wrapper page.

When embed_json_ld is provided and within the byte cap, it is inlined as a data island for the round-trip optimisation.