Module memory

Module memory 

In-memory storage backend.

Designed for tests. The state lives in a single Arc<RwLock<HashMap<String, (Bytes, ResourceMeta)>>>. Change events are broadcast to all registered watchers; a watcher only receives events for paths that are equal to, or descend from, the path it was registered with.

Structs

MemoryBackend
In-memory Storage implementation.