Module client

Module client 

acl:ClientCondition — gate authorisation on the requesting client.

A ClientCondition is satisfied when the request context’s client_id matches one of the listed acl:client IRIs, when the client is a member of a listed acl:clientGroup, or when the condition names a public class (foaf:Agent).

Structs

ClientConditionBody
Body of an acl:ClientCondition.
ClientConditionEvaluator
Default evaluator for acl:ClientCondition.